package com.diagbot.facade;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import com.diagbot.entity.BasDeptInfo;
import com.diagbot.entity.BasDoctorInfo;
import com.diagbot.entity.BehospitalInfo;
import com.diagbot.entity.DoctorAdvice;
import com.diagbot.entity.HomeDiagnoseInfo;
import com.diagbot.entity.HomeOperationInfo;
import com.diagbot.entity.HomePage;
import com.diagbot.entity.MedRecordType;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.MedicalRecordContent;
import com.diagbot.service.impl.BasDeptInfoServiceImpl;
import com.diagbot.service.impl.BasDoctorInfoServiceImpl;
import com.diagbot.service.impl.BehospitalInfoServiceImpl;
import com.diagbot.service.impl.DoctorAdviceServiceImpl;
import com.diagbot.service.impl.HomeDiagnoseInfoServiceImpl;
import com.diagbot.service.impl.HomeOperationInfoServiceImpl;
import com.diagbot.service.impl.HomePageServiceImpl;
import com.diagbot.service.impl.MedRecordTypeServiceImpl;
import com.diagbot.service.impl.MedicalRecordContentServiceImpl;
import com.diagbot.service.impl.MedicalRecordServiceImpl;
import com.diagbot.util.DBConn;

@Component
public class DataFacade{
	
	@Autowired
	@Qualifier("homePageServiceImpl")
	private HomePageServiceImpl homePageServiceImpl;
	
	@Autowired
	@Qualifier("behospitalInfoServiceImpl")
	private BehospitalInfoServiceImpl behospitalInfoServiceImpl;
	
	@Autowired
	@Qualifier("doctorAdviceServiceImpl")
	private DoctorAdviceServiceImpl doctorAdviceServiceImpl;
	
	@Autowired
	@Qualifier("medicalRecordServiceImpl")
	private MedicalRecordServiceImpl medicalRecordServiceImpl;
	
	@Autowired
	@Qualifier("medicalRecordContentServiceImpl")
	private MedicalRecordContentServiceImpl medicalRecordContentServiceImpl;
	
	@Autowired
	@Qualifier("medRecordTypeServiceImpl")
	private MedRecordTypeServiceImpl medRecordTypeServiceImpl;
	
	@Autowired
	@Qualifier("homeDiagnoseInfoServiceImpl")
	private HomeDiagnoseInfoServiceImpl homeDiagnoseInfoServiceImpl;
	
	@Autowired
	@Qualifier("homeOperationInfoServiceImpl")
	private HomeOperationInfoServiceImpl homeOperationInfoServiceImpl;
	
	@Autowired
	@Qualifier("basDeptInfoServiceImpl")
	private BasDeptInfoServiceImpl basDeptInfoServiceImpl;
	
	@Autowired
	@Qualifier("basDoctorInfoServiceImpl")
	private BasDoctorInfoServiceImpl basDoctorInfoServiceImpl;
	
	
	public void initData() {
		//初始化病案首页
		//addHomePage(null);
		//病案诊断
		//addHomeDiagnose(null);
		//病案手术
		//addHomeOperation(null);
		//初始化病历信息
		//addBehospitalInfo(null);
		//初始化医嘱信息
		//addDoctorAdvice(null);
		//初始化文书类型
		//addMedicalRecordType(null);
		//初始化文书基本信息
		//addMedicalRecord(null);
		//初始化文书内容
		//addMedicalRecordContent(null);
		
		 // 6 秒一次：秒 分 时 日 月 周
	    
		addDeptInfo(null);
		
		//addDoctorInfo(null);
		
	}
	
	/**
	 * 医生信息
	 * @return
	 */
	public Boolean addDoctorInfo(List<BasDoctorInfo> basDoctorInfoList) {
		if(basDoctorInfoList==null || basDoctorInfoList.size()==0){
			basDoctorInfoList=DBConn.getBasDoctorInfo();
		}
		return basDoctorInfoServiceImpl.saveBatch(basDoctorInfoList);
	}
	
	/**
	 * 科室信息
	 * @returnDeptInfo
	 */
	public Boolean addDeptInfo(List<BasDeptInfo> basDeptInfoList) {
		if(basDeptInfoList==null || basDeptInfoList.size()==0){
			basDeptInfoList=DBConn.getDeptInfo();
		}
		return basDeptInfoServiceImpl.saveBatch(basDeptInfoList);
	}
	
	/**
	 * 病案手术
	 * @return
	 */
	public Boolean addHomeOperation(List<HomeOperationInfo> homeOperationList) {
		if(homeOperationList==null || homeOperationList.size()==0){
			homeOperationList=DBConn.getHomeOperation();
		}
		return homeOperationInfoServiceImpl.saveBatch(homeOperationList);
	}
	
	/**
	 * 病案诊断
	 * @return
	 */
	public Boolean addHomeDiagnose(List<HomeDiagnoseInfo> homeDiagnoseList) {
		if(homeDiagnoseList==null || homeDiagnoseList.size()==0){
			homeDiagnoseList=DBConn.getHomeDiagnose();
		}
		return homeDiagnoseInfoServiceImpl.saveBatch(homeDiagnoseList);
	}
	
	/**
	 * 从视图中获取文书类型
	 * @return
	 */
	public Boolean addMedicalRecordType(List<MedRecordType> medicalRecordTypeList) {
		if(medicalRecordTypeList==null || medicalRecordTypeList.size()==0){
			medicalRecordTypeList=DBConn.getMedicalRecordType();
		}
		return medRecordTypeServiceImpl.saveBatch(medicalRecordTypeList);
	}
	
	/**
	 * 从视图中获取文书内容
	 * @return
	 */
	public Boolean addMedicalRecordContent(List<MedicalRecordContent> medicalRecordContentList){
		if(medicalRecordContentList==null || medicalRecordContentList.size()==0){
			medicalRecordContentList=DBConn.getMedicalRecordContent();
		}
		return medicalRecordContentServiceImpl.saveBatch(medicalRecordContentList);
	}
	
	/**
	 * 从视图中获取文书类型
	 * @return
	 */
	public Boolean addMedicalRecord(List<MedicalRecord> medicalRecordList){
		if(medicalRecordList==null || medicalRecordList.size()==0){
			medicalRecordList=DBConn.getMedicalRecord();
		}
		return medicalRecordServiceImpl.saveBatch(medicalRecordList);
	}
	
	
	/**
	 * 从视图获取病案首页信息
	 */
	public Boolean addHomePage(List<HomePage> homePage) {
		if(homePage==null || homePage.size()==0){
			homePage=DBConn.getHomePage();
		}
		return homePageServiceImpl.saveBatch(homePage);
	}
	
	/**
	 * 从视图中获取医嘱信息
	 * @return
	 */
	public Boolean addDoctorAdvice(List<DoctorAdvice> doctorAdviceList) {
		if(doctorAdviceList==null || doctorAdviceList.size()==0){
			doctorAdviceList=DBConn.getDoctorAdvice();
		}
		return doctorAdviceServiceImpl.saveBatch(doctorAdviceList);
	}
	
	/**
	 * 获取病历信息
	 * @return
	 */
	public Boolean addBehospitalInfo(List<BehospitalInfo> behospitalInfoList) {
		if(behospitalInfoList==null || behospitalInfoList.size()==0){
			behospitalInfoList=DBConn.getBehospitalInfo();
		}
		return behospitalInfoServiceImpl.saveBatch(behospitalInfoList);
	}
	
}
