package com.diagbot.util;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;
import java.util.List;
import java.util.ResourceBundle;

import com.diagbot.entity.BasDeptInfo;
import com.diagbot.entity.BasDoctorInfo;
import com.diagbot.entity.BehospitalInfo;
import com.diagbot.entity.DoctorAdvice;
import com.diagbot.entity.HomeDiagnoseInfo;
import com.diagbot.entity.HomeOperationInfo;
import com.diagbot.entity.HomePage;
import com.diagbot.entity.MedRecordType;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.MedicalRecordContent;
import com.diagbot.vo.FBasDeptInfoVO;
import com.diagbot.vo.FBasDoctorInfoVO;
import com.diagbot.vo.FBehospitalInfoVO;
import com.diagbot.vo.FDoctorAdviceVO;
import com.diagbot.vo.FHomeDiagnoseVO;
import com.diagbot.vo.FHomeOperationVO;
import com.diagbot.vo.FHomePageVO;
import com.diagbot.vo.FMedicalRecordContentVO;
import com.diagbot.vo.FMedicalRecordTypeVO;
import com.diagbot.vo.FMedicalRecordVO;
import com.google.common.collect.Lists;

public class DBConn {
	
	private static final String DRIVER = getValue("jdbc.driverClassName");
    private static final String URL = getValue("jdbc.url");
    private static final String USERNAME = getValue("jdbc.username");
    private static final String PASSWORD = getValue("jdbc.password");
    
    private Connection connection = null;
    private PreparedStatement sta = null;
	private ResultSet rs = null;
	
	/**
     * 读取属性文件中的信息
     *
     * @param key
     * @return
     */
    private static String getValue(String key) {
        // 资源包绑定
        ResourceBundle bundle = ResourceBundle.getBundle("jdbc");
        return bundle.getString(key);
    }
    
    /**
	 * 加载驱动程序
	 */
	static {
		try {
			Class.forName(DRIVER);
		} catch (ClassNotFoundException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @return 连接对象
	 */
	public Connection getConnection() {
		try {
			connection = DriverManager.getConnection(URL,USERNAME,PASSWORD);
		} catch (SQLException e) {

			e.printStackTrace();
		}
		return connection;
	}


	/**
	 * @param sql
	 *            sql语句  增加，删除，修改
	 * @param obj
	 *            参数
	 * @return
	 */
	public int update(String sql, Object... obj) {
		int count = 0;
		connection = getConnection();
		try {
			sta = connection.prepareStatement(sql);
			if (obj != null) {
				for (int i = 0; i < obj.length; i++) {
					sta.setObject(i + 1, obj[i]);
				}
			}
			count = sta.executeUpdate();
		} catch (SQLException e) {
			e.printStackTrace();
		} finally{
		
			close();
		}
		return count;
	}

	/**
	 * @param sql sql语句
	 * @param obj 参数
	 * @return 数据集合
	 */
	public ResultSet Query(String sql,Object...obj){
		connection=getConnection();
		try {
			sta=connection.prepareStatement(sql);
			if(obj!=null){
				for(int i=0;i<obj.length;i++){
					sta.setObject(i+1, obj[i]);
				}
			}
			rs=sta.executeQuery();
		} catch (SQLException e) {
			e.printStackTrace();
		}
		return rs;
	}
	
	/**
	 * 关闭资源
	 */
	public void close() {
		try {
			if (rs != null) {
				rs.close();
			}
		} catch (SQLException e) {
			e.printStackTrace();
		} finally {
			try {
				if (sta != null) {
					sta.close();
				}
			} catch (SQLException e2) {
				e2.printStackTrace();
			} finally {
				if (connection != null) {
					try {
						connection.close();
					} catch (SQLException e) {
						e.printStackTrace();
					}
				}
			}
		}
	}
	
	/**
	 * 医生信息
	 * @return
	 */
	public static List<BasDoctorInfo> getBasDoctorInfo() {
		List<BasDoctorInfo> basDoctorInfoList=Lists.newLinkedList();
		
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from GI_USERINFO";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FBasDoctorInfoVO basDoctorInfoVO=new FBasDoctorInfoVO();
				basDoctorInfoVO.setDoctorId(rs.getString("YHRYBH"));//医生ID
				basDoctorInfoVO.setHospitalId(Long.valueOf("1"));//医院ID
				basDoctorInfoVO.setDeptId(rs.getString("ZZKSID"));//科室ID
				basDoctorInfoVO.setName(rs.getString("YHRYMC"));//医生姓名
				basDoctorInfoVO.setProfessor(rs.getString("YHRYZC"));//职称
				
				BasDoctorInfo basDoctorInfo=new BasDoctorInfo();
				BeanUtil.copyProperties(basDoctorInfoVO, basDoctorInfo);
				
				basDoctorInfoList.add(basDoctorInfo);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		return basDoctorInfoList;
	}
	
	/**
	 * 科室信息
	 * @returnDeptInfo
	 */
	public static List<BasDeptInfo> getDeptInfo() {
		List<BasDeptInfo> basDeptInfoList=Lists.newLinkedList();
		
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from HI_DEPTINFO_CX where XGCZSJ BETWEEN TO_DATE('2020-03-01', 'yyyy-MM-dd') and TO_DATE('2020-03-30', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FBasDeptInfoVO basDeptInfoVO=new FBasDeptInfoVO();
				basDeptInfoVO.setDeptId(rs.getString("ZZKSID"));//科室编码
				basDeptInfoVO.setHospitalId(Long.valueOf("1"));//医院ID
				basDeptInfoVO.setDeptName(rs.getString("ZZKSMC"));//科室名称
				basDeptInfoVO.setDeptType(rs.getString("ZZKSLB"));//科室类别
				basDeptInfoVO.setSpell(rs.getString("HZSRM1"));//首字母拼音
				basDeptInfoVO.setStation(rs.getString("FLKSID"));//区域类别
				
				BasDeptInfo basDeptInfo=new BasDeptInfo();
				BeanUtil.copyProperties(basDeptInfoVO, basDeptInfo);
				
				basDeptInfoList.add(basDeptInfo);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		return basDeptInfoList;
	}
	
	/**
	 * 从视图中获取医嘱信息
	 * @return
	 */
	public static List<DoctorAdvice> getDoctorAdvice(){
		List<DoctorAdvice> doctorAdviceList=Lists.newLinkedList();
		
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from BR_DOCTADVICE_CX where CJCXRQ BETWEEN TO_DATE('2020-03-01', 'yyyy-MM-dd') and TO_DATE('2020-03-30', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FDoctorAdviceVO doctorAdviceVO=new FDoctorAdviceVO();
				doctorAdviceVO.setDoctorAdviceId(rs.getString("BRYZID"));//病人医嘱ID
				doctorAdviceVO.setHospitalId(Long.valueOf("1"));//医院ID
				doctorAdviceVO.setBehospitalCode(rs.getString("BRYZID"));//病人ID
				doctorAdviceVO.setOrderDoctorName(rs.getString("YSKDPB"));//医生开单判别
				doctorAdviceVO.setFrequency(rs.getString("YZPLPB"));//医嘱频率判别
				doctorAdviceVO.setParentTypeId(rs.getString("FLYZID"));//父类医嘱ID
				doctorAdviceVO.setDoctorAdviceType(rs.getString("YZLXPB"));//医嘱类型判别
				doctorAdviceVO.setUsageNum(rs.getString("YCSYSL"));//一次使用数量
				doctorAdviceVO.setUsageUnit(rs.getString("YCYLDW"));//一次用量单位
				doctorAdviceVO.setDose(rs.getString("YZDCJL"));//医嘱单次剂量
				doctorAdviceVO.setDoseUnit(rs.getString("DCJLDW"));//单次剂量单位
				doctorAdviceVO.setMedModeType(rs.getString("GYFSID"));//给药方式
				doctorAdviceVO.setDaFrequency(rs.getString("YZPLID"));//医嘱频率
				doctorAdviceVO.setDaDealType(rs.getString("YZCLLX"));//医嘱处理类型
				doctorAdviceVO.setDaStartDate(rs.getDate("YZKSSJ"));//医嘱开始时间
				doctorAdviceVO.setDaItemName(rs.getString("YZXMMC"));//医嘱项目名称
				doctorAdviceVO.setDaStatus(rs.getString("YZZTPB"));//医嘱状态判别
				doctorAdviceVO.setDaStopDate(rs.getDate("YZJSSJ"));//医嘱结束时间
				doctorAdviceVO.setDaGroupNo(rs.getString("YZTZXH"));//医嘱同组序号
				doctorAdviceVO.setDaPrescriptionType(rs.getString("YZCFLX"));//医嘱处方类型
				doctorAdviceVO.setDaMedType(rs.getString("YZLYLX"));//医嘱领药类型
				doctorAdviceVO.setDoctorNotice(rs.getString("YSZTSM"));//医生嘱托
				doctorAdviceVO.setDoctorId(rs.getString("KDYSID"));//开单医生ID
				doctorAdviceVO.setDoctorName(rs.getString("KDYSXM"));//开单医生姓名
				
				//doctorAdviceVO.set
				
				DoctorAdvice doctorAdvice=new DoctorAdvice();
				BeanUtil.copyProperties(doctorAdviceVO, doctorAdvice);
				
				doctorAdviceList.add(doctorAdvice);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return doctorAdviceList;
	}

	/**
	 * 获取病历信息
	 * @return
	 */
	public static List<BehospitalInfo> getBehospitalInfo() {
		List<BehospitalInfo> behospitalInfoList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from BR_INPATIENTINFO_CX where CJCXRQ BETWEEN TO_DATE('2020-01-01', 'yyyy-MM-dd') and TO_DATE('2020-01-20', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FBehospitalInfoVO behospitalInfoVO=new FBehospitalInfoVO();
				behospitalInfoVO.setBehospitalCode(rs.getString("BRZYID"));//病人住院ID
				behospitalInfoVO.setHospitalId("1");//医院ID
				behospitalInfoVO.setName(rs.getString("BRDAXM"));//姓名
				behospitalInfoVO.setSex(rs.getString("BRDAXB"));//性别
				behospitalInfoVO.setBirthday(rs.getDate("BRCSRQ"));//出生日期
				behospitalInfoVO.setFileCode(rs.getString("BRDABH"));//档案号
				behospitalInfoVO.setWardCode(rs.getString("ZYBQID"));//病区编码
				behospitalInfoVO.setWardName(rs.getString("ZYBQMC"));//病区名称
				behospitalInfoVO.setBehDeptId(rs.getString("ZYKSID"));//住院科室ID
				behospitalInfoVO.setBehDeptName(rs.getString("ZYKSMC"));//住院科室名称
				behospitalInfoVO.setBedCode(rs.getString("ZYCWID"));//床位号
				behospitalInfoVO.setBedName(rs.getString("ZYCWHM"));//床位名称
				behospitalInfoVO.setInsuranceName(rs.getString("BRLBID"));//医保类别
				behospitalInfoVO.setJobType(rs.getString("BRXZID"));//职业
				behospitalInfoVO.setBehospitalDate(rs.getDate("BRRYRQ"));//入院时间
				behospitalInfoVO.setLeaveHospitalDate(rs.getDate("BRCYRQ"));//出院时间
				behospitalInfoVO.setDiagnoseIcd(rs.getString("JBDMID"));//疾病ICD编码
				behospitalInfoVO.setDiagnose(rs.getString("JBMSXX"));//疾病名称
				behospitalInfoVO.setDoctorId(rs.getString("ZZYSID"));//医生ID
				behospitalInfoVO.setDoctorName(rs.getString("ZZYSXM"));//医生姓名
				
				behospitalInfoVO.setGmtCreate(new Date());
				
				BehospitalInfo behospitalInfo=new BehospitalInfo();
				BeanUtil.copyProperties(behospitalInfoVO, behospitalInfo);
				behospitalInfoList.add(behospitalInfo);
				
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		return behospitalInfoList;
	}
	
	/**
	 * 从视图获取病案首页信息
	 */
	public static List<HomePage> getHomePage() {
		List<HomePage> homePageList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from BR_RECHOME_CX where BAZKRQ BETWEEN TO_DATE('2020-01-01', 'yyyy-MM-dd') and TO_DATE('2020-01-01', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FHomePageVO homePageVO=new FHomePageVO();
				homePageVO.setHomePageId(rs.getString("BASYID"));//病案首页ID
				homePageVO.setHospitalId(Long.valueOf("1"));//医院ID
				homePageVO.setBehospitalCode(rs.getString("BRZYID"));//病人住院序号
				homePageVO.setHospitalCode(rs.getString("ZZJGID"));//组织机构id
				homePageVO.setHospitalName(rs.getString("ZZJGMC"));//医疗机构名称
				homePageVO.setOrgCode(rs.getString("ZZJGBH"));//医疗机构代码
				homePageVO.setPayType(rs.getString("YLFKLB"));//医疗付费方式
				homePageVO.setHealthCard(rs.getString("BRJKKH"));//健康卡号
				homePageVO.setBehospitalNum(rs.getString("BRZYCS"));//住院次数
				homePageVO.setFileCode(rs.getString("BRBABH"));//病案号
				homePageVO.setName(rs.getString("BRBAXM"));//姓名
				homePageVO.setSex(rs.getString("BRBAXB"));//性别
				homePageVO.setBirthday(rs.getDate("BRCSRQ"));//出生日期
				
				homePageVO.setGmtCreate(new Date());
				
				HomePage homePage=new HomePage();
				BeanUtil.copyProperties(homePageVO, homePage);
				homePageList.add(homePage);
				
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return homePageList;
	}
	
	/**
	 * 从视图中获取文书类型
	 * @return
	 */
	public static List<MedicalRecord> getMedicalRecord(){
		List<FMedicalRecordVO> medicalRecordVOList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from MR_MEDICALRECORDS_CX where BCJLSJ BETWEEN TO_DATE('2020-02-01', 'yyyy-MM-dd') and TO_DATE('2020-04-30', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FMedicalRecordVO medicalRecordVO=new FMedicalRecordVO();
				medicalRecordVO.setRecId(rs.getString("BLCJID"));
				medicalRecordVO.setHospitalId(Long.valueOf("1"));//医院ID
				medicalRecordVO.setBehospitalCode(rs.getString("BRZYID"));//病人住院ID
				medicalRecordVO.setOrgCode(rs.getString("ZZJGDM"));//组织机构代码
				medicalRecordVO.setRecTypeId(rs.getString("BLLBID"));//病历类别编号
				medicalRecordVO.setRecDate(rs.getString("BCJLSJ"));//病历日期
				medicalRecordVO.setRecTitle(rs.getString("BCJLMC"));//病历标题
				
				medicalRecordVO.setGmtCreate(new Date());
				
				medicalRecordVOList.add(medicalRecordVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		List<MedicalRecord> medicalRecordList=BeanUtil.listCopyTo(medicalRecordVOList, MedicalRecord.class);
		return medicalRecordList;
	}
	
	/**
	 * 从视图中获取文书内容
	 * @return
	 */
	public static List<MedicalRecordContent> getMedicalRecordContent(){
		List<FMedicalRecordContentVO> mrContentVOList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from MR_MRCONTENT_CX where CJCXRQ BETWEEN TO_DATE('2020-02-01', 'yyyy-MM-dd') and TO_DATE('2020-02-20', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FMedicalRecordContentVO mrContentVO=new FMedicalRecordContentVO();
				//oracle.sql.BLOB blob = (oracle.sql.BLOB)rs.getBlob("BLJLNR");
				//mrContentVO.setContentBlob(blob);
				mrContentVO.setHospitalId(Long.valueOf("1"));
				mrContentVO.setRecId(rs.getString("BLJLID"));
				
				mrContentVO.setGmtCreate(new Date());
				mrContentVOList.add(mrContentVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		List<MedicalRecordContent> mrContentList=BeanUtil.listCopyTo(mrContentVOList, MedicalRecordContent.class);
		return mrContentList;
	}
	
	/**
	 * 从视图中获取文书类型
	 * @return
	 */
	public static List<MedRecordType> getMedicalRecordType(){
		List<FMedicalRecordTypeVO> mrTypeVOList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from AR_MEDIRECCLASS_CX";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FMedicalRecordTypeVO mrTypeVO=new FMedicalRecordTypeVO();
				mrTypeVO.setTypeId(rs.getString("BLLBID"));
				mrTypeVO.setHospitalId(Long.valueOf("1"));
				mrTypeVO.setTypeName(rs.getString("BLLBMC"));
				mrTypeVO.setObjName(rs.getString("BLLBFW"));
				mrTypeVO.setSpell(rs.getString("HZSRM1"));
				mrTypeVOList.add(mrTypeVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		List<MedRecordType> medicalRecordTypeList=BeanUtil.listCopyTo(mrTypeVOList, MedRecordType.class);
		return medicalRecordTypeList;
	}
	
	/**
	 * 病案诊断
	 * @return
	 */
	public static List<HomeDiagnoseInfo> getHomeDiagnose(){
		List<HomeDiagnoseInfo> homeDiagnoseVOList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from BR_RECDIAGNOSE_CX where CJCXRQ BETWEEN TO_DATE('2020-02-01', 'yyyy-MM-dd') and TO_DATE('2020-04-30', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FHomeDiagnoseVO homeDiagnoseVO=new FHomeDiagnoseVO();
				homeDiagnoseVO.setHomePageId(rs.getString("BASYID"));//病案首页ID
				homeDiagnoseVO.setHospitalId(Long.valueOf("1"));//医院ID
				homeDiagnoseVO.setDiagnoseOrderNo(rs.getString("BAZDXH"));//诊断序号
				homeDiagnoseVO.setDiagnoseType(rs.getString("ZDLBDM"));//诊断类别
				homeDiagnoseVO.setDiagnoseTypeShort(rs.getString("ZCZDPB"));//诊断判别
				homeDiagnoseVO.setDiagnoseName(rs.getString("ZDJBMC"));//诊断名称
				homeDiagnoseVO.setBehospitalType(rs.getString("ZGQKDM"));//入院情况
				homeDiagnoseVO.setLeaveHospitalType(rs.getString("RYQKBM"));//出院情况
				//homeDiagnoseVO.setPathologyDiagnose(rs.getString("BASYID"));//病理号
				homeDiagnoseVO.setIcdCode(rs.getString("ICDM"));//诊断编码
				
				homeDiagnoseVO.setGmtCreate(new Date());
				
				HomeDiagnoseInfo homeDiagnoseInfo=new HomeDiagnoseInfo();
				BeanUtil.copyProperties(homeDiagnoseVO, homeDiagnoseInfo);
				homeDiagnoseVOList.add(homeDiagnoseInfo);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		return homeDiagnoseVOList;
	}
	
	/**
	 * 病案手术
	 * @return
	 */
	public static List<HomeOperationInfo> getHomeOperation() {
		List<FHomeOperationVO> homeOperationVOList=Lists.newLinkedList();
		try {
			DBConn dbconn=new DBConn();
			String sql="select * from BR_RECOPERATION_CX where CJCXRQ BETWEEN TO_DATE('2020-02-01', 'yyyy-MM-dd') and TO_DATE('2020-04-30', 'yyyy-MM-dd')";
			ResultSet rs =dbconn.Query(sql, null);
			while(rs.next()){
				FHomeOperationVO homeOperationVO=new FHomeOperationVO();
				homeOperationVO.setHomePageId(rs.getString("BASYID"));//病案首页ID
				homeOperationVO.setHospitalId(Long.valueOf("1"));//医院ID
				homeOperationVO.setOperationOrderNo(rs.getString("BRSSXH"));//手术序号
				homeOperationVO.setOperationDate(rs.getDate("BRSSRQ"));//手术日期
				homeOperationVO.setOperationCode(rs.getString("SSDMID"));//手术编码
				homeOperationVO.setOperationDoctorId(rs.getString("SSYSID"));//手术医生
				homeOperationVO.setFirstAssistantId(rs.getString("YZHSID"));//一助医生
				homeOperationVO.setSecondAssistantId(rs.getString("EZHSID"));//二助医生
				homeOperationVO.setCutLevel(rs.getString("QKDJDM"));//切口等级
				homeOperationVO.setHealingLevel(rs.getString("YHDJDM"));//愈合等级
				homeOperationVO.setOperationName(rs.getString("BRSSMC"));//手术名称
				homeOperationVO.setOperationLevel(rs.getString("SSJBID"));//手术级别
				homeOperationVO.setAnaesthesiaName(rs.getString("MZFFMC"));//麻醉方式
				homeOperationVO.setShamOperationName(rs.getString("NSSMC"));//拟手术名称
				homeOperationVO.setGmtCreate(new Date());
				
				homeOperationVOList.add(homeOperationVO);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		List<HomeOperationInfo> homeOperationList=BeanUtil.listCopyTo(homeOperationVOList, HomeOperationInfo.class);
		return homeOperationList;
	}
	
	public static void main(String[] args) throws Exception {
		
	}
}
