package com.diagbot.web;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.FBehospitalInfoDTO;
import com.diagbot.dto.FDoctorAdviceDTO;
import com.diagbot.dto.FHomeDiagnoseDTO;
import com.diagbot.dto.FHomePageDTO;
import com.diagbot.dto.FMedicalRecordContentDTO;
import com.diagbot.dto.FMedicalRecordDTO;
import com.diagbot.dto.FMedicalRecordTypeDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.BehospitalInfo;
import com.diagbot.entity.DoctorAdvice;
import com.diagbot.entity.HomeDiagnoseInfo;
import com.diagbot.entity.HomeOperationInfo;
import com.diagbot.entity.HomePage;
import com.diagbot.entity.MedRecordType;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.MedicalRecordContent;
import com.diagbot.facade.DataFacade;
import com.diagbot.util.BeanUtil;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/qc/data")
@Api(value = "病案首页API", tags = { "病案首页API" })
@SuppressWarnings("unchecked")
public class DataController {

	@Autowired
    private DataFacade dataFacade;
	
	@ApiOperation(value = "获取医院病案首页信息[by:gaodm]",notes = "")
	@PostMapping("/initData")
	@SysLogger("initData")
	public RespDTO<Boolean> initData() {
		//return RespDTO.onSuc(dataFacade.initData());
		return null;
	}
	
	@ApiOperation(value = "获取医院病案首页信息[by:gaodm]",notes = "")
	@PostMapping("/getHomePage")
	@SysLogger("getHomePage")
	public RespDTO<Boolean> getHomePage(List<FHomePageDTO> homePageDTOList) {
		List<HomePage> homePageList=BeanUtil.listCopyTo(homePageDTOList, HomePage.class);
		return RespDTO.onSuc(dataFacade.addHomePage(homePageList));
	}
	
	@ApiOperation(value = "获取病案手术信息[by:gaodm]",notes = "")
	@PostMapping("/getHomeOperation")
	@SysLogger("getHomeOperation")
	public RespDTO<Boolean> getHomeOperation(List<FHomeDiagnoseDTO> homeOperationDTO) {
		List<HomeOperationInfo> homeOperationList=BeanUtil.listCopyTo(homeOperationDTO, HomeOperationInfo.class);
		return RespDTO.onSuc(dataFacade.addHomeOperation(homeOperationList));
	}
	
	@ApiOperation(value = "获取病案诊断信息[by:gaodm]",notes = "")
	@PostMapping("/getHomeDiagnose")
	@SysLogger("getHomeDiagnose")
	public RespDTO<Boolean> getHomeDiagnose(List<FHomeDiagnoseDTO> homeDiagnoseDTOList) {
		List<HomeDiagnoseInfo> homeDiagnoseList=BeanUtil.listCopyTo(homeDiagnoseDTOList, HomeDiagnoseInfo.class);
		return RespDTO.onSuc(dataFacade.addHomeDiagnose(homeDiagnoseList));
	}
	
	@ApiOperation(value = "获取文书类型信息[by:]",notes = "")
	@PostMapping("/getMedicalRecordType")
	@SysLogger("getMedicalRecordType")
	public RespDTO<Boolean> getMedicalRecordType(List<FMedicalRecordTypeDTO> medlRecordTypeDTOList) {
		List<MedRecordType> medlRecordTypeList=BeanUtil.listCopyTo(medlRecordTypeDTOList, MedRecordType.class);
		return RespDTO.onSuc(dataFacade.addMedicalRecordType(medlRecordTypeList));
	}
	
	
	@ApiOperation(value = "获取文书内容信息[by:gaodm]",notes = "")
	@PostMapping("/getMedicalRecordContent")
	@SysLogger("getMedicalRecordContent")
	public RespDTO<Boolean> getMedicalRecordContent(List<FMedicalRecordContentDTO> medlRecordContentDTOList) {
		List<MedicalRecordContent> medicalRecordContentList=BeanUtil.listCopyTo(medlRecordContentDTOList, MedicalRecordContent.class);
		return RespDTO.onSuc(dataFacade.addMedicalRecordContent(medicalRecordContentList));
	}

	@ApiOperation(value = "获取文书基本信息[by:gaodm]",notes = "")
	@PostMapping("/getMedicalRecord")
	@SysLogger("getMedicalRecord")
	public RespDTO<Boolean> getMedicalRecord(List<FMedicalRecordDTO> medicalRecordDTOList) {
		List<MedicalRecord> medicalRecordList=BeanUtil.listCopyTo(medicalRecordDTOList, MedicalRecord.class);
		return RespDTO.onSuc(dataFacade.addMedicalRecord(medicalRecordList));
	}
	
	@ApiOperation(value = "获取医院医嘱信息[by:gaodm]",notes = "")
	@PostMapping("/getDoctorAdvice")
	@SysLogger("getDoctorAdvice")
	public RespDTO<Boolean> getDoctorAdvice(List<FDoctorAdviceDTO> doctorAdviceDTOList) {
		List<DoctorAdvice> doctorAdviceList=BeanUtil.listCopyTo(doctorAdviceDTOList, DoctorAdvice.class);
		return RespDTO.onSuc(dataFacade.addDoctorAdvice(doctorAdviceList));
	}
	
	@ApiOperation(value = "获取病历信息[by:gaodm]",notes = "")
	@PostMapping("/getBehospitalInfo")
	@SysLogger("getBehospitalInfo")
	public RespDTO<Boolean> getBehospitalInfo(List<FBehospitalInfoDTO> behospitalInfoDTOList) {
		List<BehospitalInfo> behospitalInfoList=BeanUtil.listCopyTo(behospitalInfoDTOList, BehospitalInfo.class);
		return RespDTO.onSuc(dataFacade.addBehospitalInfo(behospitalInfoList));
	}
	
}
